%global _hardened_build 1

Summary:        Apple IIgs Emulator
Name:           gsplus
Version:	0.14
Release:        9%{?dist}
License:        GPLv2
Group:          Applications/Emulators

URL:            https://apple2.gs/plus/
Source0:	https://github.com/digarok/gsplus/archive/v%{version}.tar.gz#/%name-%version.tar.gz
Source1:        %{name}-getroms.sh
Source4:        %{name}.png
Source5:        %{name}.desktop

Patch0:         %{name}-xdg.patch

Requires:       xorg-x11-fonts-misc
Requires:       pulseaudio-utils

BuildRequires:  gcc gcc-c++
BuildRequires:  perl
BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib
BuildRequires:  libX11-devel
BuildRequires:  libXext-devel
BuildRequires:  freetype-devel
BuildRequires:  SDL2-devel
BuildRequires:  SDL2_image-devel
BuildRequires:  libpcap-devel


%description
gsplus is a portable (in the programming sense) Apple IIgs emulator, based on
the KEGS cross-platform IIgs emulator by Kent Dickey. The base emulator builds
and runs on all of the same platforms that KEGS did, and the new capabilities
are being integrated as contributors have time and interest.


%prep
%autosetup -p1

%build
# Setup linux vars
pushd src
cat >vars <<EOF
TARGET = gsplus
NAME = gsplus
PERL = perl
CC = gcc
LD = gcc
AS = cc

OBJECTS = \$(OBJECTS1) \$(TFEOBJ) \$(ATOBJ) \$(PCAPOBJ) \$(FSTOBJ) sdl2_driver.o sdl2snd_driver.o

# C Compiler Options
CCOPTS = $RPM_OPT_FLAGS -std=gnu99 -DHAVE_SDL -DHAVE_TFE -DHAVE_ATBRIDGE -DTOGGLE_STATUS -I/usr/include/SDL2 -I/usr/include/freetype2
# C++ Compiler Options
CPPOPTS = $RPM_OPT_FLAGS -DHAVE_TFE -DHAVE_SDL -DTOGGLE_STATUS -DHAVE_ATBRIDGE -I/usr/include/freetype2 -I/usr/include/SDL2

EXTRA_LIBS = -lfreetype -lSDL2 -lSDL2_image -ldl -lm -lstdc++
OPTS = -DGSPLUS_LITTLE_ENDIAN
SUFFIX =
LDFLAGS =
LDOPTS = -I.
EXTRA_SPECIALS =
EOF

%make_build

%clean
rm -rf $RPM_BUILD_ROOT

%install
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}
install -D -m 0755 gsplus           $RPM_BUILD_ROOT/%{_bindir}/%{name}.bin
install -D -m 0755 %{SOURCE1}       $RPM_BUILD_ROOT/%{_bindir}/%{name}-getroms.sh
install -D -m 0644 lib/NoBoot.po    $RPM_BUILD_ROOT/%{_datadir}/%{name}/NoBoot.po
install -D -m 0644 lib/letgothl.ttf $RPM_BUILD_ROOT/%{_datadir}/%{name}/lib/letgothl.ttf
install -D -m 0644 %{SOURCE4}       $RPM_BUILD_ROOT/%{_datadir}/pixmaps/%{name}.png

# Initial config for clean boot.
cat >$RPM_BUILD_ROOT/%{_datadir}/%{name}/config.txt.dist <<EOF
# GSplus configuration file version %{version}

s5d1 =
s5d2 =

s6d1 =
s6d2 =

s7d1 = %{_datadir}/%{name}/NoBoot.po

g_joystick_type = 0
g_cfg_rom_path = ROM.03

EOF

# Startup wrapper
cat >$RPM_BUILD_ROOT/%{_bindir}/%{name} <<'EOF'
#!/usr/bin/env bash
# Simple wrapper to start GSplus via PulseAudio OSS Wrapper to enable
# sound via the older /dev/dsp interface.

# First run, get roms if needed and setup config file.
if [[ ! -f ${HOME}/.config/%{name}/config.txt && -n ${HOME} ]]; then
    /usr/bin/%{name}-getroms.sh
fi

cd %{_datadir}/%{name}
exec padsp %{_bindir}/%{name}.bin -audio 1
EOF

desktop-file-install --dir=$RPM_BUILD_ROOT%{_datadir}/applications %{SOURCE5}

%files
%defattr(-,root,root)
%license LICENSE.txt
%doc COPYRIGHT.txt README.md doc/gsplusmanual.pdf
%attr(755,root,root) %{_bindir}/*
%{_datadir}/%{name}/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*


%changelog
* Sat Jun 26 2021 Greg Wildman <greg@techno.co.za> - 0.14-9
- Add the manual doc to package.

* Sun Apr 21 2019 Greg Wildman <greg@techno.co.za> - 0.14-8
- Update to release version.

* Wed Aug 29 2018 Greg Wildman <greg@techno.co.za> - 0.14git6ebebfa-4
- Update to latest commit.

* Mon Aug 27 2018 Greg Wildman <greg@techno.co.za> - 0.14git712c079-3
- Update to latest commit.

* Sat Aug 25 2018 Greg Wildman <greg@techno.co.za> - 0.14git17f22c3-2
- Update to latest commit.

* Thu Jun 28 2018 Greg Wildman <greg@techno.co.za> - 0.13-11
- Patch for XDG folder compliance

* Thu Jun 28 2018 Greg Wildman <greg@techno.co.za> - 0.13-10
- Update config file detection

* Sun Sep 25 2016 Greg Wildman <greg@techno.co.za> - 0.31-7
- Include GUI .desktop file and appdata xml.

* Sun Sep 25 2016 Greg Wildman <greg@techno.co.za> - 0.31-6
- Include ROM01 as well.

* Fri Dec 18 2015 Greg Wildman <greg@techno.co.za> - 3.2-1
- Initial spec.


